@@ -3,6 +3,7 @@
 import sys
 import argparse
 from json.decoder import JSONDecodeError
+import jellex
 from jello.lib import load_json, pyquery, Json
 
 import pygments
@@ -22,12 +23,22 @@ from prompt_toolkit.formatted_text import PygmentsTokens
 from prompt_toolkit.lexers import PygmentsLexer
 
 
-parser = argparse.ArgumentParser()
-parser.add_argument('filename')
+parser = argparse.ArgumentParser(description='Interactive JSON Explorer using Python syntax.')
+parser.add_argument('-v', '--version', action='version',
+                    version='%(prog)s {version}'.format(version=jellex.__version__),
+                    help='version information')
+parser.add_argument('filename',
+                    help='JSON or JSON Lines file to open')
 args = parser.parse_args()
 
-with open(args.filename) as file:
-    file_text = file.read()
+
+try:
+    with open(args.filename) as file:
+        file_text = file.read()
+
+except Exception as e:
+    print(f'jellex: There was a problem opening that file:\n        {e}', file=sys.stderr)
+    sys.exit(1)
 
 def get_json(data, query):
     """Returns a Tuple of (<JSON Response>, <Exception Message>)"""
@@ -48,7 +59,7 @@ def get_json(data, query):
         sys.exit(1)
 
     except Exception as e:
-        return last_output, str(e)
+        return last_output, f'{e.__class__.__name__}:\n{e}'
 
 
 # Initial content
